**To delete dataset content**

The following ``delete-dataset-content`` example deletes the content of the specified dataset. ::

    aws iotanalytics delete-dataset-content \
        --dataset-name mydataset

This command produces no output.

For more information, see `DeleteDatasetContent <https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeleteDatasetContent.html>`__ in the *AWS IoT Analytics API Reference*.
